///  The color corresponds to the style of the image.
enum ColorImageStyle {
  /// graphic art
  graphicArt(1, 0.045, 0.015),

  /// textures, textiles.
  texturesAndTextiles(2, 0.048, 0.014);

  /// enum initialization
  const ColorImageStyle(this.kl, this.k1, this.k2);

  /// Lightness factor, the value range is 0 to 1.
  final double kl;

  /// A constant that adjusts for the nonlinearity of the Lab* color space.
  /// The Lab color space has different perception of color difference in different regions, so it needs to be adjusted to improve its accuracy. This is what k1 does。
  /// It applies a larger adjustment in the lower luminance value region of the Lab* color space to better match the perception of the human visual system.
  final double k1;

  /// A constant that adjusts for the nonlinearity of the Lab* color space.
  /// The role of k2 is to apply a larger adjustment in the more saturated color regions on the ab* plane to better match the perception of the human visual system.
  final double k2;
}
