import 'package:idkit/idkit.dart';

extension IDKitList<T> on List<T> {
  /// Determine whether the element is the last element of the collection
  bool isLast(T element) {
    if (isEmpty) return false;
    return last == element;
  }

  /// Determine whether the element is the first element of the collection
  bool isFirst(T element) {
    if (isEmpty) return false;
    return first == element;
  }

  /// The collection object is copied, but the elements of the collection content are not copied.
  List<T> copy() {
    final List<T> list = [];
    for (var i = 0; i < length; i++) {
      list.add(this[i]);
    }
    return list;
  }

  /// Copy the elements of the content of the collection object, the collection does not copy.
  List<T> copyItems({T Function(T)? mapCopy}) {
    if (mapCopy.isNoNull) {
      for (var i = 0; i < length; i++) {
        this[i] = mapCopy!.call(this[i]);
      }
    }
    return this;
  }

  /// To do a deep copy, you first need to copy the collection. If the target copy object mapCopy is null, the collection will be copied directly.
  /// Otherwise, the collection itself needs to be copied, and the elements inside the collection also need to be copied.
  List<T> deepCopy({T Function(T)? mapCopy}) {
    List<T> list = [];
    if (mapCopy.isNull) {
      for (var i = 0; i < length; i++) {
        list.add(this[i]);
      }
    } else {
      for (var i = 0; i < length; i++) {
        list.add(mapCopy!.call(this[i]));
      }
    }
    return list;
  }
}
